
using System;
using System.Drawing;

using MonoTouch.Foundation;
using MonoTouch.UIKit;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.iOSEdition;

namespace ZeeTest.iOS
{
	public partial class MapViewController : UIViewController
	{
		public MapViewController () : base ("MapViewController", null)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		private MapView iOSMap;
		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			// Set the main view frame
			View.Frame = UIScreen.MainScreen.Bounds;
			View.BackgroundColor = UIColor.White;
			View.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;

			// Create MapView
			iOSMap = new MapView(View.Frame);
			iOSMap.MapUnit = GeographyUnit.DecimalDegree;  
			iOSMap.BackgroundColor = new UIColor(233, 229, 220, 200);
			iOSMap.ZoomLevelSet = new BingMapsZoomLevelSet();
			Marker thinkGeoLocation = new Marker();
			thinkGeoLocation.Position = new PointShape(-28.5537, 153.5084);
			thinkGeoLocation.SetImage(UIImage.FromBundle("Pin"), UIControlState.Normal);
			MarkerOverlay markerOverlay = new MarkerOverlay();
			markerOverlay.Markers.Add(thinkGeoLocation);
			iOSMap.Overlays.Add("markerOverlay", markerOverlay);
			BingMapsTileOverlay bingMapOverlay = new BingMapsTileOverlay("bing key here");
			iOSMap.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
			iOSMap.Overlays.Add(bingMapOverlay);
			string rootPath = Environment.GetFolderPaaaaaath(Environment.SpecialFolder.MyDocuments);
			bingMapOverlay.MapType = BingMapsMapType.AerialWithLabels;
			bingMapOverlay.TileCache = new FileBitmapTileCache(rootPath + "/CacheImages", "Road");
			bingMapOverlay.TileCache.TileMatrix.BoundingBoxUnit = GeographyUnit.Meter;
			bingMapOverlay.TileCache.TileMatrix.BoundingBox = bingMapOverlay.GetBoundingBox();
			bingMapOverlay.TileCache.ImageFormat = TileImageFormat.Jpeg;
			iOSMap.CurrentExtent=new RectangleShape (151.209389, -32.860000, 151.219389, -33.86000);
			iOSMap.ZoomTo(iOSMap.CurrentExtent);        
			View.AddSubview(iOSMap);
			iOSMap.Refresh();
		}

	}
}

